//>>built
define("dojo/nls/dojo_fi-fi",{"dijit/form/nls/validate":{invalidMessage:"Annettu arvo ei kelpaa.",missingMessage:"T\u00e4m\u00e4 arvo on pakollinen.",rangeMessage:"T\u00e4m\u00e4 arvo on sallitun alueen ulkopuolella.",_localized:{}},"dojo/cldr/nls/number":{scientificFormat:"#E0","currencySpacing-afterCurrency-currencyMatch":"[:^S:]",infinity:"\u221e",superscriptingExponent:"\u00d7",list:";",percentSign:"%",minusSign:"\u2212","currencySpacing-beforeCurrency-surroundingMatch":"[:digit:]","decimalFormat-short":"000\u00a0bilj'.'",
"currencySpacing-afterCurrency-insertBetween":"\u00a0",nan:"ep\u00e4luku",plusSign:"+","currencySpacing-afterCurrency-surroundingMatch":"[:digit:]","currencySpacing-beforeCurrency-currencyMatch":"[:^S:]",currencyFormat:"#,##0.00\u00a0\u00a4",perMille:"\u2030",group:"\u00a0",percentFormat:"#,##0\u00a0%","decimalFormat-long":"000 biljoonaa",decimalFormat:"#,##0.###",decimal:",","currencySpacing-beforeCurrency-insertBetween":"\u00a0",exponential:"E",_localized:{}},"dijit/form/nls/ComboBox":{previousMessage:"Edelliset valinnat",
nextMessage:"Lis\u00e4\u00e4 valintoja",_localized:{}},"dijit/nls/loading":{loadingState:"Lataus on meneill\u00e4\u00e4n...",errorState:"On ilmennyt virhe.",_localized:{}},"dijit/nls/common":{buttonOk:"OK",buttonCancel:"Peruuta",buttonSave:"Tallenna",itemClose:"Sulje",_localized:{}},"dijit/_editor/nls/commands":{bold:"Lihavointi",copy:"Kopioi",cut:"Leikkaa","delete":"Poista",indent:"Sisenn\u00e4",insertHorizontalRule:"Vaakasuuntainen viiva",insertOrderedList:"Numeroitu luettelo",insertUnorderedList:"Numeroimaton luettelo",
italic:"Kursivointi",justifyCenter:"Tasaus keskelle",justifyFull:"Tasaus",justifyLeft:"Tasaus vasemmalle",justifyRight:"Tasaus oikealle",outdent:"Ulonna",paste:"Liit\u00e4",redo:"Tee uudelleen",removeFormat:"Poista muotoilu",selectAll:"Valitse kaikki",strikethrough:"Yliviivaus",subscript:"Alennettu",superscript:"Korotettu",underline:"Alleviivaus",undo:"Kumoa",unlink:"Poista linkki",createLink:"Luo linkki",toggleDir:"Vaihda suuntaa",insertImage:"Lis\u00e4\u00e4 kuva",insertTable:"Lis\u00e4\u00e4 taulukko/muokkaa taulukkoa",
toggleTableBorder:"Ota taulukon kehys k\u00e4ytt\u00f6\u00f6n/poista kehys k\u00e4yt\u00f6st\u00e4",deleteTable:"Poista taulukko",tableProp:"Taulukon ominaisuudet",htmlToggle:"HTML-l\u00e4hde",foreColor:"Edustav\u00e4ri",hiliteColor:"Taustav\u00e4ri",plainFormatBlock:"Kappaletyyli",formatBlock:"Kappaletyyli",fontSize:"Fonttikoko",fontName:"Fontin nimi",tabIndent:"Sarkainsisennys",fullScreen:"Vaihda koko n\u00e4ytt\u00f6",viewSource:"N\u00e4yt\u00e4 HTML-l\u00e4hde",print:"Tulosta",newPage:"Uusi sivu",
systemShortcut:'Toiminto "${0}" on k\u00e4ytett\u00e4viss\u00e4 selaimessa vain n\u00e4pp\u00e4imist\u00f6n pikatoiminnolla. K\u00e4yt\u00e4 seuraavaa: ${1}.',ctrlKey:"Ctrl+${0}",appleKey:"\u2318${0}",_localized:{}},"dijit/_editor/nls/FontChoice":{1:"xx-small",2:"x-small",3:"small",4:"medium",5:"large",6:"x-large",7:"xx-large",fontSize:"Koko",fontName:"Fontti",formatBlock:"Muotoile",serif:"serif","sans-serif":"sans-serif",monospace:"monospace",cursive:"cursive",fantasy:"fantasy",noFormat:"Ei mit\u00e4\u00e4n",
p:"Kappale",h1:"Otsikko",h2:"Alatason otsikko",h3:"Alimman tason otsikko",pre:"Esimuotoiltu",_localized:{}},"dojox/editor/plugins/nls/latinEntities":{iexcl:"yl\u00f6salainen huutomerkki",cent:"sentin merkki",pound:"punnan merkki",curren:"valuuttamerkki",yen:"jenin merkki\nyuanin merkki",brvbar:"katkopystyviiva",sect:"pyk\u00e4l\u00e4merkki",uml:"treema\ntilaa viev\u00e4 treema",copy:"tekij\u00e4noikeusmerkki",ordf:"feminiinisen j\u00e4rjestysluvun merkki",laquo:"vasemmalle osoittava kaksinkertainen kulmalainausmerkki\nvasemmalle osoittava kulmalainausmerkki",
not:"negaation merkki\nei-merkki",shy:"ehdollinen tavuviiva\npehme\u00e4 tavuviiva\ntavutusvihje",reg:"rekister\u00f6idyn tavaramerkin merkki\nrekister\u00f6ity tavaramerkki -merkki",macr:"macron\nviiva-aksentti\npituusmerkki\np\u00e4\u00e4llekk\u00e4isviiva",deg:"astemerkki",plusmn:"plus-miinus-merkki\nplus- tai miinusmerkki",sup2:"yl\u00e4indeksi kaksi\nneli\u00f6\ntoinen potenssi",sup3:"yl\u00e4indeksi kolme\nkuutio\nkolmas potenssi",acute:"akuutti\nakuuttiaksentti",micro:"mikro-merkki",para:"kappaleen merkki\nkappalemerkki",
middot:"keskipiste\nrivinkeskinen piste\ngeorgialainen pilkku\nkreikkalainen keskipiste",cedil:"sedilji\ntilaa viev\u00e4 sedilji\ncedilla",sup1:"yl\u00e4indeksi yksi",ordm:"maskuliinisen j\u00e4rjestysluvun merkki",raquo:"oikealle osoittava kaksinkertainen kulmalainausmerkki\noikealle osoittava kulmalainausmerkki",frac14:"nelj\u00e4sosan merkki\nnelj\u00e4sosa",frac12:"puolikkaan merkki\npuolikas",frac34:"kolmen nelj\u00e4sosan merkki\nkolme nelj\u00e4sosaa",iquest:"yl\u00f6salainen kysymysmerkki",
Agrave:"iso A ja gravis\nversaali A ja gravis",Aacute:"iso A ja akuutti\niso A ja akuuttiaksentti\nversaali A ja akuutti",Acirc:"iso A ja sirkumfleksi\nversaali A ja sirkumfleksi",Atilde:"iso A ja tilde\nversaali A ja tilde\niso A ja aaltoviiva\nversaali A ja aaltoviiva",Auml:"iso \u00c4\nversaali \u00c4",Aring:"iso \u00c5\nversaali \u00c5\niso ruotsalainen o\nversaali ruotsalainen o",AElig:"iso AE\nversaali AE\niso ligatuuri AE\nversaaliligatuuri AE\niso tanskalainen \u00e4\nversaali tanskalainen \u00e4",
Ccedil:"iso C ja sedilji\nversaali C ja sedilji",Egrave:"iso E ja gravis\nversaali E ja gravis",Eacute:"iso E ja akuutti\niso E ja akuuttiaksentti\nversaali E ja akuutti",Ecirc:"iso E ja sirkumfleksi\nversaali E ja sirkumfleksi",Euml:"iso E ja treema\nversaali E ja treema",Igrave:"iso I ja gravis\nversaali I ja gravis",Iacute:"iso I ja akuutti\niso I ja akuuttiaksentti\nversaali I ja akuutti",Icirc:"iso I ja sirkumfleksi\nversaali I ja sirkumfleksi",Iuml:"iso I ja treema\nversaali I ja treema",ETH:"iso eth\nversaali eth",
Ntilde:"iso N ja tilde\nversaali N ja tilde\niso N ja aaltoviiva\nversaali N ja aaltoviiva",Ograve:"iso O ja gravis\nversaali O ja gravis",Oacute:"iso O ja akuutti\niso O ja akuuttiaksentti\nversaali O ja akuutti",Ocirc:"iso O ja sirkumfleksi\nversaali O ja sirkumfleksi",Otilde:"iso O ja tilde\nversaali O ja tilde\niso O ja aaltoviiva\nversaali O ja aaltoviiva",Ouml:"iso O ja treema\nversaali O ja treema",times:"kertomerkki",Oslash:"iso tanskalainen \u00f6\nversaali tanskalainen \u00f6\niso O ja vinoviiva\nversaali O ja vinoviiva\niso O, jossa on poikkiviiva\nversaali O, jossa on poikkiviiva",
Ugrave:"iso U ja gravis\nversaali U ja gravis",Uacute:"iso U ja akuutti\niso U ja akuuttiaksentti\nversaali U ja akuutti",Ucirc:"iso U ja sirkumfleksi\nversaali U ja sirkumfleksi",Uuml:"iso U ja treema\nversaali U ja treema\niso saksalainen y\nversaali saksalainen y",Yacute:"iso Y ja akuutti\niso Y ja akuuttiaksentti\nversaali Y ja akuutti",THORN:"iso thorn\nversaali thorn",szlig:"pieni kaksois-s\ngemena kaksois-s\npieni saksalainen kaksois-s\ngemena saksalainen kaksois-s",agrave:"pieni a ja gravis\ngemena a ja gravis",
aacute:"pieni a ja akuutti\ngemena a ja akuutti\npieni a ja akuuttiaksentti",acirc:"pieni a ja sirkumfleksi\ngemena a ja sirkumfleksi",atilde:"pieni a ja tilde\ngemena a ja tilde\npieni a ja aaltoviiva\ngemena a ja aaltoviiva",auml:"pieni \u00e4\ngemena \u00e4",aring:"pieni \u00e5\ngemena \u00e5\npieni ruotsalainen o\ngemena ruotsalainen o",aelig:"pieni ae\ngemena ae\npieni ligatuuri ae\ngemenaligatuuri ae\npieni tanskalainen \u00e4\ngemena tanskalainen \u00e4",ccedil:"pieni c ja sedilji\ngemena c ja sedilji",
egrave:"pieni e ja gravis\ngemena e ja gravis",eacute:"pieni e ja akuutti\ngemena e ja akuutti\npieni e ja akuuttiaksentti",ecirc:"pieni e ja sirkumfleksi\ngemena e ja sirkumfleksi",euml:"pieni e ja treema\ngemena e ja treema",igrave:"pieni i ja gravis\ngemena e ja gravis",iacute:"pieni i ja akuutti\ngemena i ja akuutti\npieni i ja akuuttiaksentti",icirc:"pieni i ja sirkumfleksi\ngemena i ja sirkumfleksi",iuml:"pieni i ja treema\ngemena i ja treema",eth:"pieni eth\ngemena eth",ntilde:"pieni n ja tilde\ngemena n ja tilde\npieni n ja aaltoviiva\ngemena n ja aaltoviiva",
ograve:"pieni o ja gravis\ngemena o ja gravis",oacute:"pieni o ja akuutti\ngemena o ja akuutti\npieni o ja akuuttiaksentti",ocirc:"pieni o ja sirkumfleksi\ngemena o ja sirkumfleksi",otilde:"pieni o ja tilde\ngemena o ja tilde\npieni o ja aaltoviiva\ngemena o ja aaltoviiva",ouml:"pieni \u00f6\ngemena \u00f6",divide:"jakomerkki",oslash:"pieni tanskalainen \u00f6\ngemena tanskalainen \u00f6\npieni o ja vinoviiva\ngemena o ja vinoviiva\npieni o, jossa on poikkiviiva\ngemena o, jossa on poikkiviiva",ugrave:"pieni u ja gravis\ngemena u ja gravis",
uacute:"pieni u ja akuutti\ngemena u ja akuutti\npieni u ja akuuttiaksentti",ucirc:"pieni u ja sirkumfleksi\ngemena u ja sirkumfleksi",uuml:"pieni u ja treema\ngemena u ja treema\npieni saksalainen y\ngemena saksalainen y",yacute:"pieni y ja akuutti\ngemena y ja akuutti\npieni y ja akuuttiaksentti",thorn:"pieni thorn\ngemena thorn",yuml:"pieni y ja treema\ngemena y ja treema",fnof:"pieni f, jossa koukku\ngemena f, jossa koukku\nfunktio\nguldeni",Alpha:"iso alfa\nversaali alfa",Beta:"iso beeta\nversaali beeta",
Gamma:"iso gamma\nversaali gamma",Delta:"iso delta\nversaali delta",Epsilon:"iso epsilon\nversaali epsilon",Zeta:"iso zeeta\nversaali zeeta",Eta:"iso eeta\nversaali eeta",Theta:"iso theeta\nversaali theeta",Iota:"iso ioota\nversaali ioota",Kappa:"iso kappa\nversaali kappa",Lambda:"iso lambda\nversaali lambda",Mu:"iso myy\nversaali myy",Nu:"iso nyy\nversaali nyy",Xi:"iso ksii\nversaali ksii",Omicron:"iso omikron\nversaali omikron",Pi:"iso pii\nversaali pii",Rho:"iso rhoo\nversaali rhoo",Sigma:"iso sigma\nversaali sigma",
Tau:"iso tau\nversaali tau",Upsilon:"iso ypsilon\nversaali ypsilon",Phi:"iso fii\nversaali fii",Chi:"iso khii\nversaali khii",Psi:"iso psii\nversaali psii",Omega:"iso oomega\nversaali oomega",alpha:"pieni alfa\ngemena alfa",beta:"pieni beeta\ngemena beeta",gamma:"pieni gamma\ngemena gamma",delta:"pieni delta\ngemena delta",epsilon:"pieni epsilon\ngemena epsilon",zeta:"pieni zeeta\ngemena zeeta",eta:"pieni eeta\ngemena eeta",theta:"pieni theeta\ngemena theeta",iota:"pieni ioota\ngemena ioota",kappa:"pieni kappa\ngemena kappa",
lambda:"pieni lambda\ngemena lambda",mu:"pieni myy\ngemena myy",nu:"pieni nyy\ngemena nyy",xi:"pieni ksii\ngemena ksii",omicron:"pieni omikron\ngemena omikron",pi:"pieni pii\ngemena pii",rho:"pieni rhoo\ngemena rhoo",sigmaf:"pieni sananloppuinen sigma\ngemena sananloppuinen sigma",sigma:"pieni sigma\ngemena sigma",tau:"pieni tau\ngemena tau",upsilon:"pieni ypsilon\ngemena ypsilon",phi:"pieni fii\ngemena fii",chi:"pieni khii\ngemena khii",psi:"pieni psii\ngemena psii",omega:"pieni oomega\ngemena oomega",
thetasym:"pieni theeta\ngemena theeta",upsih:"ypsilon, jossa koukku",piv:"pii-merkki",bull:"luetelmamerkki\nluetelmapallo\npieni musta ympyr\u00e4",hellip:"kolme pistett\u00e4\nkolme pistett\u00e4 vaakasuunnassa\nellipsi",prime:"yl\u00e4puolinen indeksointipilkku\nindeksointipilkku\nminuutit\njalat",Prime:"kaksinkertainen yl\u00e4puolinen indeksointipilkku\nsekunnit\ntuumat",oline:"yl\u00e4viiva",frasl:"murtoluvun vinoviiva\nmurtolukuviiva",weierp:"iso kaunokirjoitus-P\npotenssijoukko\nWeierstrassin p",
image:"goottilainen iso I\ngoottilainen versaali I\nimaginaarinen osa",real:"goottilainen iso R\ngoottilainen versaali R\nreaaliosa",trade:"tavaramerkki\ntavaramerkin merkki",alefsym:"alef-merkki\nalef\nensimm\u00e4inen transfiniittinen kardinaali",larr:"vasen nuoli\nnuoli vasemmalle",uarr:"yl\u00e4nuoli\nnuoli yl\u00f6s\nyl\u00f6sp\u00e4in osoittava nuoli",rarr:"oikea nuoli\nnuoli oikealle",darr:"alanuoli\nnuoli alas\nalasp\u00e4in osoittava nuoli",harr:"nuoli vasemmalle ja oikealle",crarr:"rivinvaihtomerkki",
lArr:"kaksoisnuoli vasemmalle",uArr:"kaksoisnuoli yl\u00f6s",rArr:"kaksoisnuoli oikealle",dArr:"kaksoisnuoli alas",hArr:"kaksoisnuoli vasemmalle ja oikealle",forall:"kaikkikvanttori\nuniversaalikvanttori",part:"osittaisderivaatta",exist:"olemassaolokvanttori",empty:"tyhj\u00e4 joukko\nhalkaisija",nabla:"nabla\ngradientti",isin:"joukkoon kuulumisen merkki",notin:"joukkoon kuulumattomuuden merkki",ni:"k\u00e4\u00e4nteinen joukkoon kuulumisen merkki",prod:"tulo\ntulon merkki",sum:"summa",minus:"miinusmerkki",
lowast:"t\u00e4hti\nasteriski",radic:"neli\u00f6juuri\njuurimerkki",prop:"verrannollinen",infin:"\u00e4\u00e4ret\u00f6n\n\u00e4\u00e4rett\u00f6m\u00e4n merkki",ang:"kulma",and:"looginen ja-merkki",or:"looginen tai-merkki",cap:"leikkauksen merkki\nleikkaus",cup:"yhdisteen merkki\nyhdiste\nunioni","int":"integraalimerkki\nintegraali",there4:"loogisen seuraamuksen merkki\njoten\nsiis",sim:"tildeoperaattori\nlikiarvo",cong:"suunnilleen yht\u00e4 suuri kuin -merkki",asymp:"likimain yht\u00e4 suuri kuin -merkki\nasymptoottinen",
ne:"eri suuri kuin -merkki\nerisuuruusmerkki",equiv:"identtisesti yht\u00e4 suuri kuin -merkki",le:"pienempi tai yht\u00e4 suuri kuin -merkki",ge:"suurempi tai yht\u00e4 suuri kuin -merkki",sub:"osajoukon merkki",sup:"ylijoukon merkki",nsub:"osajoukkosuhteen negaation merkki",sube:"osajoukkosuhteen tai yht\u00e4l\u00e4isyyden merkki",supe:"ylijoukkosuhteen tai yht\u00e4l\u00e4isyyden merkki",oplus:"ympyr\u00e4ss\u00e4 oleva plusmerkki\nsuora summa",otimes:"ympyr\u00e4ss\u00e4 oleva kertomerkki\nvektoritulo\nristitulo",
perp:"kohtisuoruusmerkki",sdot:"pisteoperaattori",lceil:"vasen kattosymboli",rceil:"oikea kattosymboli",lfloor:"vasen lattiasymboli",rfloor:"oikea lattiasymboli",lang:"vasemmalle osoittava kulmasulje",rang:"oikealle osoittava kulmasulje",loz:"vinoneli\u00f6\nnelikovero",spades:"musta korttipakan pata",clubs:"musta korttipakan risti\napila",hearts:"musta korttipakan hertta\nsyd\u00e4n",diams:"musta korttipakan ruutu",OElig:"iso ligatuuri OE\nversaaliligatuuri OE",oelig:"pieni ligatuuri oe\ngemenaligatuuri oe",
Scaron:"iso hattu-S\nversaali hattu-S",scaron:"pieni hattu-s\ngemena hattu-s",Yuml:"iso Y ja treema\nversaali Y ja treema",circ:"tarkkeenomainen sirkumfleksi",tilde:"pieni tilde",ensp:"n-v\u00e4li\nn-kirjaimen levyinen v\u00e4li",emsp:"m-v\u00e4li\nm-kirjaimen levyinen v\u00e4li",thinsp:"kapea v\u00e4li",zwnj:"leveydet\u00f6n erottava merkki",zwj:"leveydet\u00f6n yhdist\u00e4v\u00e4 merkki",lrm:"vasemmalta oikealle -merkki",rlm:"oikealta vasemmalle -merkki",ndash:"n-viiva\nlyhyt ajatusviiva",mdash:"m-viiva\npitk\u00e4 ajatusviiva",
lsquo:"yl\u00f6salainen puolilainausmerkki",rsquo:"puolilainausmerkki",sbquo:"rivinalinen puolilainausmerkki",ldquo:"yl\u00f6salainen kokolainausmerkki",rdquo:"kokolainausmerkki",bdquo:"rivinalinen kokolainausmerkki",dagger:"risti",Dagger:"kaksoisristi",permil:"promillemerkki",lsaquo:"vasemmalle osoittava kulmapuolilainausmerkki",rsaquo:"oikealle osoittava kulmapuolilainausmerkki",euro:"euron merkki",_localized:{}},"dojox/editor/plugins/nls/InsertEntity":{insertEntity:"Lis\u00e4\u00e4 symboli",_localized:{}},
"dojo/nls/colors":{aliceblue:"vaaleanharmaansininen",antiquewhite:"antiikinvalkoinen",aqua:"sinivihre\u00e4",aquamarine:"vedenvihre\u00e4",azure:"taivaansininen",beige:"vaaleanruskea",bisque:"vaaleanruskea",black:"musta",blanchedalmond:"kuorittu manteli",blue:"sininen",blueviolet:"sinivioletti",brown:"ruskea",burlywood:"puunruskea",cadetblue:"meren vihre\u00e4",chartreuse:"kellanvihre\u00e4",chocolate:"suklaanruskea",coral:"koralli",cornflowerblue:"syv\u00e4nsininen",cornsilk:"maissinkeltainen",crimson:"karmiininpunainen",
cyan:"syaani",darkblue:"tummansininen",darkcyan:"tumma turkoosi",darkgoldenrod:"tumma kultapiisku",darkgray:"tummanharmaa",darkgreen:"tummanvihre\u00e4",darkgrey:"tummanharmaa",darkkhaki:"tumma khaki",darkmagenta:"tumma magenta",darkolivegreen:"tummanoliivinvihre\u00e4",darkorange:"tummanoranssi",darkorchid:"tumma orkidea",darkred:"tummanpunainen",darksalmon:"tumma lohenpunainen",darkseagreen:"tumma merenvihre\u00e4",darkslateblue:"tumma siniharmaa",darkslategray:"tummanharmaa",darkslategrey:"tummanharmaa",
darkturquoise:"tumma turkoosi",darkviolet:"tummanvioletti",deeppink:"syv\u00e4 vaaleanpunainen",deepskyblue:"tumma taivaansininen",dimgray:"himme\u00e4nharmaa",dimgrey:"himme\u00e4nharmaa",dodgerblue:"Dodger-sininen",firebrick:"poltetun tiilen punainen",floralwhite:"kukanvalkoinen",forestgreen:"mets\u00e4nvihre\u00e4",fuchsia:"purppura",gainsboro:"gainsboro",ghostwhite:"lakananvalkoinen",gold:"kulta",goldenrod:"kullanruskea",gray:"harmaa",green:"vihre\u00e4",greenyellow:"vihre\u00e4nkeltainen",grey:"harmaa",
honeydew:"hunajameloninvihre\u00e4",hotpink:"pinkki",indianred:"kirkkaanpunainen",indigo:"indigo",ivory:"norsunluu",khaki:"khaki",lavender:"laventeli",lavenderblush:"laventelinpunainen",lawngreen:"ruohonvihre\u00e4",lemonchiffon:"sitruunankeltainen",lightblue:"vaaleansininen",lightcoral:"vaalea koralli",lightcyan:"vaalea syaani",lightgoldenrodyellow:"vaalea kultapiiskunkeltainen",lightgray:"vaaleanharmaa",lightgreen:"vaaleanvihre\u00e4",lightgrey:"vaaleanharmaa",lightpink:"vaaleanpunainen",lightsalmon:"vaalea lohenpunainen",
lightseagreen:"vaalea merenvihre\u00e4",lightskyblue:"vaalea taivaansininen",lightslategray:"vaaleanharmaa",lightslategrey:"vaaleanharmaa",lightsteelblue:"vaalea ter\u00e4ksensininen",lightyellow:"vaaleankeltainen",lime:"vaaleanvihre\u00e4",limegreen:"limetinvihre\u00e4",linen:"pellavanvaalea",magenta:"magenta",maroon:"kastanjanruskea",mediumaquamarine:"keskivaalea vedenvihre\u00e4",mediumblue:"keskisininen",mediumorchid:"keskivaalea orkidea",mediumpurple:"keskivaalea violetti",mediumseagreen:"keskivaalea merenvihre\u00e4",
mediumslateblue:"keskivaalea siniharmaa",mediumspringgreen:"keskivaalea kev\u00e4\u00e4nvihre\u00e4",mediumturquoise:"keskivaalea turkoosi",mediumvioletred:"keskivaalea lila",midnightblue:"y\u00f6nsininen",mintcream:"minttukreemi",mistyrose:"utuinen ruusu",moccasin:"nahanruskea",navajowhite:"navajonvalkoinen",navy:"laivastonsininen",oldlace:"vanha pitsi",olive:"oliivinvihre\u00e4",olivedrab:"oliivinruskea",orange:"oranssi",orangered:"oranssinpunainen",orchid:"orkidea",palegoldenrod:"haalea kultapiisku",
palegreen:"haalea vihre\u00e4",paleturquoise:"haalea turkoosi",palevioletred:"haalea lila",papayawhip:"papaijavaahto",peachpuff:"persikka",peru:"peru",pink:"vaaleanpunainen",plum:"luumunpunainen",powderblue:"harmaansininen",purple:"violetti",red:"punainen",rosybrown:"punertavanruskea",royalblue:"syv\u00e4nsininen",saddlebrown:"satulanruskea",salmon:"lohenpunainen",sandybrown:"hiekanruskea",seagreen:"merenvihre\u00e4",seashell:"simpukankuori",sienna:"siena",silver:"hopea",skyblue:"taivaansininen",
slateblue:"savensininen",slategray:"savenharmaa",slategrey:"savenharmaa",snow:"lumivalkoinen",springgreen:"kev\u00e4\u00e4nvihre\u00e4",steelblue:"ter\u00e4ksensininen",tan:"kellanruskea",teal:"sinivihre\u00e4",thistle:"ohdake",tomato:"tomaatinpunainen",transparent:"l\u00e4pin\u00e4kyv\u00e4",turquoise:"turkoosi",violet:"violetti",wheat:"vehn\u00e4nkeltainen",white:"valkoinen",whitesmoke:"savunvalkea",yellow:"keltainen",yellowgreen:"kellanvihre\u00e4",_localized:{}},"dojox/widget/nls/ColorPicker":{redLabel:"r",
greenLabel:"g",blueLabel:"b",hueLabel:"h",saturationLabel:"s",valueLabel:"v",degLabel:"\u00b0",hexLabel:"hex",huePickerTitle:"S\u00e4vyn valitsin",saturationPickerTitle:"Kyll\u00e4isyyden valitsin",_localized:{}},"dojox/editor/plugins/nls/TableDialog":{insertTableTitle:"Lis\u00e4\u00e4 taulukko",modifyTableTitle:"Muokkaa taulukkoa",rows:"Rivit:",columns:"Sarakkeet:",align:"Tasaus:",cellPadding:"Solun t\u00e4ytt\u00f6:",cellSpacing:"Solujen v\u00e4li:",tableWidth:"Taulukon leveys:",backgroundColor:"Taustav\u00e4ri:",
borderColor:"Kehyksen v\u00e4ri:",borderThickness:"Kehyksen paksuus:",percent:"prosenttia",pixels:"kuvapistett\u00e4","default":"oletus",left:"vasen",center:"keskitetty",right:"oikea",buttonSet:"Aseta",buttonInsert:"Lis\u00e4\u00e4",buttonCancel:"Peruuta",selectTableLabel:"Valitse taulukko",insertTableRowBeforeLabel:"Lis\u00e4\u00e4 rivi ennen",insertTableRowAfterLabel:"Lis\u00e4\u00e4 rivi j\u00e4lkeen",insertTableColumnBeforeLabel:"Lis\u00e4\u00e4 sarake ennen",insertTableColumnAfterLabel:"Lis\u00e4\u00e4 sarake j\u00e4lkeen",
deleteTableRowLabel:"Poista rivi",deleteTableColumnLabel:"Poista sarake",colorTableCellTitle:"Taulukon solun taustav\u00e4ri",tableContextMenuTitle:"Taulukon pikavalikko",_localized:{}},"dojox/editor/plugins/nls/PasteFromWord":{pasteFromWord:"Liit\u00e4 Word-ohjelmasta",instructions:"Liit\u00e4 sis\u00e4lt\u00f6 Word-tiedostosta alla olevaan tekstikentt\u00e4\u00e4n. Kun lis\u00e4tt\u00e4v\u00e4 sis\u00e4lt\u00f6 on mielest\u00e4si valmis, napsauta Liit\u00e4-painiketta. Voit peruuttaa lis\u00e4yksen napsauttamalla Peruuta-painiketta.",
_localized:{}},"dojox/editor/plugins/nls/InsertAnchor":{insertAnchor:"Lis\u00e4\u00e4 ankkuri",title:"Ankkurin ominaisuudet",anchor:"Nimi:",text:"Kuvaus:",set:"Aseta",cancel:"Peruuta",_localized:{}},"dojox/editor/plugins/nls/Blockquote":{blockquote:"Blockquote",_localized:{}},"dojox/editor/plugins/nls/LocalImage":{insertImageTitle:"Lis\u00e4\u00e4 kuva",url:"Kuva",browse:"Selaa...",text:"Kuvaus",set:"Lis\u00e4\u00e4",invalidMessage:"Virheellinen kuvatiedoston laji",prePopuTextUrl:"Anna kuvan URL-osoite",
prePopuTextBrowse:" tai selaa paikalliseen tiedostoon.",_localized:{}},"dojo/cldr/nls/gregorian":{"dateFormatItem-Ehm":"E h.mm a","days-standAlone-short":"su ma ti ke to pe la".split(" "),"months-format-narrow":"THMHTKHESLMJ".split(""),"field-second-relative+0":"nyt","quarters-standAlone-narrow":["1","2","3","4"],"field-weekday":"viikonp\u00e4iv\u00e4","dateFormatItem-yQQQ":"QQQ y","dateFormatItem-yMEd":"E d.M.y","field-wed-relative+0":"t\u00e4n\u00e4 keskiviikkona","field-wed-relative+1":"ensi keskiviikkona",
"dateFormatItem-GyMMMEd":"E d. MMM y G","dateFormatItem-MMMEd":"ccc d. MMM",eraNarrow:["eK","jK","jKr.","jaa."],"field-tue-relative+-1":"viime tiistaina","days-format-short":"su ma ti ke to pe la".split(" "),"dateTimeFormats-appendItem-Day-Of-Week":"{0} {1}","dateFormat-long":"d. MMMM y","field-fri-relative+-1":"viime perjantaina","field-wed-relative+-1":"viime keskiviikkona","months-format-wide":"tammikuuta helmikuuta maaliskuuta huhtikuuta toukokuuta kes\u00e4kuuta hein\u00e4kuuta elokuuta syyskuuta lokakuuta marraskuuta joulukuuta".split(" "),
"dateTimeFormat-medium":"{1} {0}","dayPeriods-format-wide-pm":"ip.","dateFormat-full":"cccc d. MMMM y","field-thu-relative+-1":"viime torstaina","dateFormatItem-Md":"d.M.","dayPeriods-format-abbr-am":"ap.","dateTimeFormats-appendItem-Second":"{0} ({2}: {1})","dayPeriods-format-wide-noon":"noon","dateFormatItem-yMd":"d.M.y","field-era":"aikakausi","dateFormatItem-yM":"L.y","months-standAlone-wide":"tammikuu helmikuu maaliskuu huhtikuu toukokuu kes\u00e4kuu hein\u00e4kuu elokuu syyskuu lokakuu marraskuu joulukuu".split(" "),
"timeFormat-short":"H.mm","quarters-format-wide":["1. nelj\u00e4nnes","2. nelj\u00e4nnes","3. nelj\u00e4nnes","4. nelj\u00e4nnes"],"dateFormatItem-yQQQQ":"QQQQ y","timeFormat-long":"H.mm.ss z","field-year":"vuosi","dateFormatItem-yMMM":"LLL y","dateTimeFormats-appendItem-Era":"{1} {0}","field-hour":"tunti","months-format-abbr":"tammikuuta helmikuuta maaliskuuta huhtikuuta toukokuuta kes\u00e4kuuta hein\u00e4kuuta elokuuta syyskuuta lokakuuta marraskuuta joulukuuta".split(" "),"field-sat-relative+0":"t\u00e4n\u00e4 lauantaina",
"field-sat-relative+1":"ensi lauantaina","timeFormat-full":"H.mm.ss zzzz","dateTimeFormats-appendItem-Week":"{0} ({2}: {1})","field-day-relative+0":"t\u00e4n\u00e4\u00e4n","field-thu-relative+0":"t\u00e4n\u00e4 torstaina","field-day-relative+1":"huomenna","field-thu-relative+1":"ensi torstaina","dateFormatItem-GyMMMd":"d. MMM y G","dateFormatItem-H":"H","months-standAlone-abbr":"tammi helmi maalis huhti touko kes\u00e4 hein\u00e4 elo syys loka marras joulu".split(" "),"quarters-format-abbr":["1. nelj.",
"2. nelj.","3. nelj.","4. nelj."],"quarters-standAlone-wide":["1. nelj\u00e4nnes","2. nelj\u00e4nnes","3. nelj\u00e4nnes","4. nelj\u00e4nnes"],"dateFormatItem-Gy":"y G","dateFormatItem-M":"L","days-standAlone-wide":"sunnuntai maanantai tiistai keskiviikko torstai perjantai lauantai".split(" "),"dayPeriods-format-abbr-noon":"noon","timeFormat-medium":"H.mm.ss","field-sun-relative+0":"t\u00e4n\u00e4 sunnuntaina","dateFormatItem-Hm":"H.mm","field-sun-relative+1":"ensi sunnuntaina","quarters-standAlone-abbr":["1. nelj.",
"2. nelj.","3. nelj.","4. nelj."],eraAbbr:["eKr.","eaa.","jKr.","jaa."],"field-minute":"minuutti","field-dayperiod":"vuorokaudenaika","days-standAlone-abbr":"su ma ti ke to pe la".split(" "),"dateFormatItem-d":"d","dateFormatItem-ms":"m.ss","quarters-format-narrow":["1","2","3","4"],"field-day-relative+-1":"eilen","dateTimeFormat-long":"{1} {0}","dayPeriods-format-narrow-am":"ap.","dateFormatItem-h":"h a","dateFormatItem-MMMd":"d. MMM","dateFormatItem-MEd":"E d.M.","dateTimeFormat-full":"{1} {0}",
"field-fri-relative+0":"t\u00e4n\u00e4 perjantaina","field-fri-relative+1":"ensi perjantaina","field-day":"p\u00e4iv\u00e4","days-format-wide":"sunnuntaina maanantaina tiistaina keskiviikkona torstaina perjantaina lauantaina".split(" "),"field-zone":"aikavy\u00f6hyke","months-standAlone-narrow":"THMHTKHESLMJ".split(""),"dateFormatItem-y":"y","dateTimeFormats-appendItem-Day":"{0} ({2}: {1})","field-year-relative+-1":"viime vuonna","field-month-relative+-1":"viime kuussa","dateTimeFormats-appendItem-Year":"{1} {0}",
"dateFormatItem-hm":"h.mm a","dateTimeFormats-appendItem-Hour":"{0} ({2}: {1})","dayPeriods-format-abbr-pm":"ip.","days-format-abbr":"su ma ti ke to pe la".split(" "),eraNames:["ennen Kristuksen syntym\u00e4\u00e4","ennen ajanlaskun alkua","j\u00e4lkeen Kristuksen syntym\u00e4n","j\u00e4lkeen ajanlaskun alun"],"dateFormatItem-yMMMd":"d. MMM y","days-format-narrow":"SMTKTPL".split(""),"field-month":"kuukausi","days-standAlone-narrow":"SMTKTPL".split(""),"dateFormatItem-MMM":"LLL","field-tue-relative+0":"t\u00e4n\u00e4 tiistaina",
"dateTimeFormats-appendItem-Quarter":"{0} ({2}: {1})","field-tue-relative+1":"ensi tiistaina","dayPeriods-format-wide-am":"ap.","dateTimeFormats-appendItem-Month":"{0} ({2}: {1})","dateTimeFormats-appendItem-Minute":"{0} ({2}: {1})","dateFormatItem-EHm":"E H.mm","field-mon-relative+0":"t\u00e4n\u00e4 maanantaina","field-mon-relative+1":"ensi maanantaina","dateFormat-short":"d.M.y","dateFormatItem-EHms":"E H.mm.ss","dateFormatItem-Ehms":"E h.mm.ss a","dayPeriods-format-narrow-noon":"n","field-second":"sekunti",
"field-sat-relative+-1":"viime lauantaina","dateFormatItem-yMMMEd":"E d. MMM y","field-sun-relative+-1":"viime sunnuntaina","field-month-relative+0":"t\u00e4ss\u00e4 kuussa","field-month-relative+1":"ensi kuussa","dateTimeFormats-appendItem-Timezone":"{0} {1}","dateFormatItem-Ed":"E d.","field-week":"viikko","dateFormat-medium":"d.M.y","field-week-relative+-1":"viime viikolla","field-year-relative+0":"t\u00e4n\u00e4 vuonna","field-year-relative+1":"ensi vuonna","dayPeriods-format-narrow-pm":"ip.",
"dateTimeFormat-short":"{1} {0}","dateFormatItem-Hms":"H.mm.ss","dateFormatItem-hms":"h.mm.ss a","dateFormatItem-GyMMM":"LLL y G","field-mon-relative+-1":"viime maanantaina","field-week-relative+0":"t\u00e4ll\u00e4 viikolla","field-week-relative+1":"ensi viikolla","dateFormatItem-yMM":"M.y","dayPeriods-standAlone-wide-pm":"ip.","field-day-relative+2":"ylihuomenna","field-day-relative+-2":"toissap\u00e4iv\u00e4n\u00e4","dateFormatItem-yMMMM":"LLLL y","dateFormatItem-yMMMMccccd":"cccc d. MMMM y","dayPeriods-standAlone-wide-am":"ap.",
_localized:{}}});
//# sourceMappingURL=dojo_fi-fi.js.map